@@ -15,13 +15,19 @@ from constants import SIMPLIFIED, TRADITIONAL, EITHER, BOTH, NEITHER
 
 from hanzidentifier import hanzidentifier
 
-if settings.TRADITIONAL_DICT:
-    print "Using traditional dictionary..."
-    _curpath=os.path.normpath( os.path.join( os.getcwd(), os.path.dirname(__file__) )  )
-    if os.path.exists(os.path.join(_curpath, 'data/dict.txt.big')):
-        jieba.set_dictionary('data/dict.txt.big')
-    else:
-        print "Warning: TRADITIONAL_DICT is enabled in settings, but the dictionary has not yet been downloaded. \n\nYou might want to try running download_data.py"
+_curpath=os.path.normpath( os.path.join( os.getcwd(), os.path.dirname(__file__) ))
+settings_path = os.environ.get('MAFAN_DICTIONARY_PATH')
+if settings_path and os.path.exists(settings_path):
+    jieba.set_dictionary(settings_path)
+elif os.path.exists(os.path.join(_curpath, 'data/dict.txt.big')):
+    jieba.set_dictionary('data/dict.txt.big')
+else:
+    try:
+        import mafan_traditional
+        jieba.set_dictionary(mafan_traditional.path)
+        print "Using traditional dictionary!"
+    except ImportError:
+        pass
 
 from jianfan import jtof as tradify, ftoj as simplify
 to_traditional = tradify
@@ -200,15 +206,14 @@ def split_text(text, include_part_of_speech=False, strip_english=False, strip_nu
 
     strip_english: remove all entries that have English or numbers in them (useful sometimes)
     """
-    # :TODO: Write doctests! Important!
 
     if not include_part_of_speech:
-        seg_list = jieba.cut_for_search(text)
+        seg_list = pseg.cut(text)
         if strip_english:
             seg_list = filter(lambda x: not contains_english(x), seg_list)
         if strip_numbers:
             seg_list = filter(lambda x: not _is_number(x), seg_list)
-        return list(seg_list)
+        return list(map(lambda i: i.word, seg_list))
     else:
         seg_list = pseg.cut(text)
         objs = map(lambda w: (w.word, w.flag), seg_list)
